<?php

Route::get('/{match?}', array('as' => 'accueil', function ($match = NULL) {
	if($match) {
		$articles = Article::select('id', 'title', 'intro_text')
							->orderBy('created_at', 'desc')
							->where('intro_text', 'like', '%'.$match.'%')
							->orwhere('full_text', 'like', '%'.$match.'%')
							->get();	
	} else {
		$articles = Article::select('id', 'title', 'intro_text')
							->orderBy('created_at', 'desc')
							->paginate(4);
	}
    return View::make('accueil',  array(
        'categories' => Categorie::all(),
        'articles' => $articles,
        'actif' => 0
    )); 
}));

Route::model('cat', 'Categorie');
Route::get('cat/{cat}', function(Categorie $categorie) {
	$articles = $categorie->articles()->orderBy('created_at', 'desc')->paginate(4);
	return View::make('accueil', array('categories' => Categorie::all(), 'articles' => $articles, 'actif' => $categorie->id));
});

Route::model('art', 'Article');
Route::get('art/{cat_id}/{art}', function($cat_id, $article) {
	//////////////////////////////////////////////////////////////
	// Log d'un utilisateur pour tester la saisie des commentaires
	$user = User::where('username', '=', 'admin')->first();
	Auth::login($user);
	//////////////////////////////////////////////////////////////
	$comments = $article->comments()->orderBy('comments.created_at', 'desc')
									->join('users', 'users.id', '=', 'comments.user_id')
									->select('users.username', 'title', 'text', 'comments.created_at')
									->get();
	return View::make('article', array('categories' => Categorie::all(), 'article' => $article, 'actif' => $cat_id, 'comments' => $comments));
});

Route::group(array('before' => 'csrf'), function () {
	
	Route::post('comment', function() {
		Comment::create(
			array(
				'title' => Input::get('title'),
				'user_id' => Auth::user()->id,
				'article_id' => Input::get('id_art'),
				'text' => Input::get('comment')
			)
		);
		return Redirect::to('art/'.Input::get('id_cat').'/'.Input::get('id_art'));
	});
	
	Route::post('find', function() {
		$match = Input::get('find');
		if($match) {
			return Redirect::route('accueil', array('match' => $match))
				->with('flash_notice', 'Résultats pour la recherche du terme '.$match);
		} else {
			return Redirect::route('accueil')
				->with('flash_error', 'Il faudrait entrer un terme pour la recherche !');
		}
	});

});

App::missing(function($exception) {
    return 'Cette page n\'existe pas !';
});

